==> illuminaHumanv1BeadID.db_1.2.0.tar.gz: illuminaHumanv1BeadID.db/man/illuminaHumanv1BeadID_dbconn.Rd <==
\name{illuminaHumanv1BeadID_dbconn}

\alias{illuminaHumanv1BeadID_dbconn}
\alias{illuminaHumanv1BeadID_dbfile}
\alias{illuminaHumanv1BeadID_dbschema}
\alias{illuminaHumanv1BeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanv1BeadID_dbconn()
  illuminaHumanv1BeadID_dbfile()
  illuminaHumanv1BeadID_dbschema(file="", show.indices=FALSE)
  illuminaHumanv1BeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanv1BeadID_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{illuminaHumanv1BeadID_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{illuminaHumanv1BeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanv1BeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanv1BeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanv1BeadID_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{illuminaHumanv1BeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanv1BeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanv1BeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanv1BeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanv1BeadID_dbconn() was created with:
  dbConnect(SQLite(), dbname=illuminaHumanv1BeadID_dbfile(), cache_size=64000, synchronous=0)

  illuminaHumanv1BeadID_dbschema()

  illuminaHumanv1BeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> illuminaHumanv1BeadID.db_1.6.0.tar.gz: illuminaHumanv1BeadID.db/man/illuminaHumanv1BeadID_dbconn.Rd <==

\name{illuminaHumanv1BeadID_dbconn}

\alias{illuminaHumanv1BeadID_dbconn}
\alias{illuminaHumanv1BeadID_dbfile}
\alias{illuminaHumanv1BeadID_dbschema}
\alias{illuminaHumanv1BeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaHumanv1BeadID_dbconn()
  illuminaHumanv1BeadID_dbfile()
  illuminaHumanv1BeadID_dbschema(file="", show.indices=FALSE)
  illuminaHumanv1BeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaHumanv1BeadID_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{illuminaHumanv1BeadID_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{illuminaHumanv1BeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaHumanv1BeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaHumanv1BeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaHumanv1BeadID_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{illuminaHumanv1BeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaHumanv1BeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaHumanv1BeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaHumanv1BeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaHumanv1BeadID_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=illuminaHumanv1BeadID_dbfile(), cache_size=64000,
  synchronous=0)

  illuminaHumanv1BeadID_dbschema()

  illuminaHumanv1BeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
